@@ -1,6 +1,6 @@
-BEFORE_INSERT = "before_insert"
-AFTER_INSERT = "after_insert"
+BEFORE_CREATE = "before_create"
+AFTER_CREATE = "after_create"
 BEFORE_UPDATE = "before_update"
 AFTER_UPDATE = "after_update"
 BEFORE_DELETE = "before_delete"
-AFTER_DELETE = "after_delete"
\ No newline at end of file
+AFTER_DELETE = "after_delete"
